##  Blocked Email Addresses
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756313d7a44101491f1d74b586c8f52_LowRes.png)
The Blocked Users tab allows you to identify which email addresses are currently on the blocked list. This list is maintained to protect our email sender's reputation. If an email delivery failed with a permanent error (e.g. a mistyped / non-existent email, a non-existent destination server), the email address will be blocked. Trying to send emails to addresses that are known to result in an error, hurts our mail reputation, which can lead to Emails being classified as spam by the mail server.
If you find an email address on the block list, which you know to be working and want to remove it from the list, please contact our support.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
